Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Field ¶
type Field struct {
Key string
Value interface{}
}
Field represents a structured log field
type Logger ¶
type Logger interface {
Debug(msg string, fields ...Field)
Info(msg string, fields ...Field)
Warn(msg string, fields ...Field)
Error(msg string, fields ...Field)
Fatal(msg string, fields ...Field)
// With creates a child logger with the provided fields
With(fields ...Field) Logger
// SetLevel dynamically changes the log level
SetLevel(level Level)
// Sync flushes any buffered log entries
Sync() error
}
Logger interface defines the behavior of the logging system
Click to show internal directories.
Click to hide internal directories.